#Step 3
#Analyze results from the simulation of COVID-19 deaths
library(reshape2)
library(ggplot2)
library(gridExtra)
library(weights)
library(dplyr)

#Make Full consistent with CorData so that same individuals are represented in both
Full_Original=Full
Full = Full[which(Full$SEQN%in%CorData$SEQN),]

#Get weights for null case
set.seed(1234)
WTS_null = rmultinom(1000,200000,Full$WTMEC2YR/sum(Full$WTMEC2YR))

##Calibration Checks
#Age
AgeDists=apply(WTS,2,function(x){wtd.hist(Full$RIDAGEYR,breaks=seq(20,85,5),right=FALSE,plot=FALSE,weight=x)$counts})
AgeDists=AgeDists/sum(AgeDists[,1])

#Plot proportions from "a" weighting with CDC-reported proportions
AgeDist_Pretty=data.frame(Age=c("20-24","25-29","30-34","35-39","40-44","45-49","50-54","55-59","60-64","65-69","70-74",
                                "75-79","80+"),Lower=apply(AgeDists,1,quantile,prob=0.025),Upper=apply(AgeDists,1,quantile,prob=0.975),
                          Median=apply(AgeDists,1,quantile,prob=0.5),Proportion=apply(AgeDists,1,mean),CDC=CDC$age)
#Get age distribution from NHANES
zz=count(Full,age,wt=WTMEC2YR)
zz=zz$n/sum(zz$n)
AgeDist_Pretty$NHANES=zz

ggplot(AgeDist_Pretty)+geom_col(aes(x=Age,y=Proportion))+geom_errorbar(aes(x=Age,ymin=Lower,ymax=Upper),width=0.5)+
  geom_point(aes(x=Age,y=CDC),colour="blue",size=5)+geom_point(aes(x=Age,y=NHANES),colour="red",shape=17,size=5)

#Mean age
#Deaths
zz=apply(WTS,2,function(x){
  wtd.mean(Full$RIDAGEYR,weights=x)
})
mean(zz)
quantile(zz,probs=c(0.025,0.975))
#NHANES
wtd.mean(Full$RIDAGEYR,weights=Full$WTMEC2YR)
#CDC
sum(CDC$age*seq(22.5,82.5,5))

#Gender
Male=apply(WTS,2,function(x){wtd.hist(Full$male,breaks=seq(0,2,1),right=FALSE,plot=FALSE,weight=x)$counts})
Male=Male/sum(Male[,1])

#Plot proportions from "a" weighting with CDC-reported proportions
Male_pretty=data.frame(Gender=c("Female","Male"),Lower=apply(Male,1,quantile,prob=0.025),Upper=apply(Male,1,quantile,prob=0.975),
                       Median=apply(Male,1,quantile,prob=0.5),Proportion=apply(Male,1,mean),CDC=CDC$male[2:1])
#Get NHANES proportions of male
zz=count(Full,male,wt=WTMEC2YR)
zz=pull(zz,n)
zz=zz/sum(zz)
Male_pretty$NHANES=zz

ggplot(Male_pretty)+geom_col(aes(x=Gender,y=Proportion),width=0.5)+geom_errorbar(aes(x=Gender,ymin=Lower,ymax=Upper),width=0.25)+
  geom_point(aes(x=Gender,y=CDC),colour="blue",size=5)+geom_point(aes(x=Gender,y=NHANES),colour="red",shape=17,size=5)

#Race/Ethnicity
RE=apply(WTS,2,function(x){
  Temp=data.frame(RIDRETH3=Full$RIDRETH3,WT=x)
  return(count(Temp,RIDRETH3,wt=WT)$n)})

RE=rbind(RE[1,]+RE[2,],RE[3:6,])
RE=RE/sum(RE[,1])

#Plot proportions from "a" weighting with CDC-reported proportions
RE_pretty=data.frame(Race_Ethnicity=c("Hispanic","NHW","AA","AAPI","Other"),Median=apply(RE,1,quantile,prob=0.5),
                     Lower=apply(RE,1,quantile,prob=0.025),Upper=apply(RE,1,quantile,prob=0.975),Proportion=apply(RE,1,mean),
                     CDC=unlist(CDC$re_NHANES))

#Get NHANES proportions of race/ethnicity
zz=count(Full,RIDRETH3,wt=WTMEC2YR)
zz=pull(zz,n)
zz=c(sum(zz[1:2]),zz[3:6])/sum(zz)
RE_pretty$NHANES=zz

ggplot(RE_pretty)+geom_col(aes(x=Race_Ethnicity,y=Proportion))+geom_errorbar(aes(x=Race_Ethnicity,ymin=Lower,ymax=Upper),width=0.5)+
  geom_point(aes(x=Race_Ethnicity,y=CDC),colour="blue",size=5)+geom_point(aes(x=Race_Ethnicity,y=NHANES),colour="red",shape=17,size=5)

chisq.test(x=RE_pretty$Proportion*200000,p=RE_pretty$CDC)
chisq.test(x=RE_pretty$Proportion*200000,p=RE_pretty$NHANES)

#Collapse to white/non-white
RE_white=rbind(RE[2,],colSums(RE[c(1,3,4,5),]))
RE_white_pretty=data.frame(Race_Ethnicity=c("Non-Hispanic White","Others"),Median=apply(RE_white,1,quantile,prob=0.5),
                           Lower=apply(RE_white,1,quantile,prob=0.025),Upper=apply(RE_white,1,quantile,prob=0.975),Proportion=apply(RE_white,1,mean),
                           CDC=c(0.508,0.492))

#Get NHANES proportions of race/ethnicity black/white
zz=count(Full,RIDRETH3,wt=WTMEC2YR)
zz=pull(zz,n)
zz=c(zz[3],sum(zz[c(1:2,4:6)]))/sum(zz)
RE_white_pretty$NHANES=zz

ggplot(RE_white_pretty)+geom_col(aes(x=Race_Ethnicity,y=Proportion))+geom_errorbar(aes(x=Race_Ethnicity,ymin=Lower,ymax=Upper),width=0.5)+
  geom_point(aes(x=Race_Ethnicity,y=CDC),colour="blue",size=5)+geom_point(aes(x=Race_Ethnicity,y=NHANES),colour="red",shape=17,size=5)

#Hypothesis Testing
#Analytic
chisq.test(x=RE_white_pretty$Proportion*200000,p=RE_white_pretty$NHANES)
#Bootstrap
#Distribution of null chi squared statistics
zz=apply(WTS_null,2,function(x){
  Temp=data.frame(REW=Full$RIDRETH3,WT=x)
  z=count(Temp,REW,wt=WT)$n
  z=c(z[3],sum(z[-3]))
  z=z/sum(z)
  return(chisq.test(x=z,p=RE_white_pretty$NHANES)$statistic)
})
1-ecdf(zz)(chisq.test(x=RE_white_pretty$Proportion,p=RE_white_pretty$NHANES)$statistic)

#Figure for publication showing calibration for age & sex
age_plot=ggplot(AgeDist_Pretty)+geom_col(aes(x=Age,y=Proportion))+
  geom_errorbar(aes(x=Age,ymin=Lower,ymax=Upper),width=0.5,size=2)+
  geom_point(aes(x=Age,y=CDC),colour="blue",size=5)+geom_point(aes(x=Age,y=NHANES),colour="red",shape=17,size=5)+
  theme(axis.text.x = element_text(angle = 45, hjust = 1),plot.title = element_text(hjust = 0.5),text=element_text(size=20))
gender_plot=ggplot(Male_pretty)+geom_col(aes(x=Gender,y=Proportion),width=0.5)+
  geom_errorbar(aes(x=Gender,ymin=Lower,ymax=Upper),width=0.25,size=2)+
  geom_point(aes(x=Gender,y=CDC),colour="blue",size=5)+geom_point(aes(x=Gender,y=NHANES),colour="red",shape=17,size=5)+
  theme(plot.title = element_text(hjust = 0.5),text=element_text(size=20))
ggsave("Calibration20200915.pdf",grid.arrange(age_plot,gender_plot,ncol=1),height=12,width=8)
ggsave("Calibration20200915.tiff",grid.arrange(age_plot,gender_plot,ncol=1),height=12,width=8)


##Distributions of Social Determinants
#Income Distribution
Income=apply(WTS,2,function(x){
  Temp=data.frame(INDHHIN2=Full$INDHHIN2,WT=x)
  return(count(Temp,INDHHIN2,wt=WT)$n)})
Income=Income/sum(Income[,1])
  
#Remove missing data
Income_complete=Income[-c(11:12,15:17),]
Income_complete=apply(Income_complete,2,function(x){x/sum(x)})
Income_pretty=data.frame(Income=c("$0 to $4,999","$5,000 to $9,999","$10,000 to $14,999","$15,000 to $19,999","$20,000 to $24,999",
                                  "$25,000 to $34,999","$35,000 to $44,999","$45,000 to $54,999","$55,000 to $64,999","$65,000 to $74,999",
                                  "$75,000 to $99,999",">$100,000"),
                         Median = apply(Income_complete,1,quantile,prob=0.5), Proportion = apply(Income_complete,1,mean),
                         Lower = apply(Income_complete,1,quantile,prob=0.025),Upper = apply(Income_complete,1,quantile,prob=0.975))

#Get NHANES proportions of income levels
zz=count(Full,INDHHIN2,wt=WTMEC2YR)
zz=zz[-c(11:12,15:17),] #Get rid of NA counts as well
zz[,2]=zz[,2]/sum(zz[,2])

Income_pretty$NHANES=pull(zz,n)

ggplot(Income_pretty)+geom_col(aes(x=Income,y=Proportion))+geom_errorbar(aes(x=Income,ymin=Lower,ymax=Upper),width=0.5)+
  geom_point(aes(x=Income,y=NHANES),col="red",shape=17,size=5)+theme(axis.text.x = element_text(angle = 60, hjust = 1))

#Hypothesis Testing
#Analytic
chisq.test(x=Income_pretty$Proportion*200000,p=Income_pretty$NHANES)
#Bootstrap
#Distribution of null chi squared statistics
zz=apply(WTS_null,2,function(x){
  Temp=data.frame(INDHHIN2=Full$INDHHIN2,WT=x)
  z=count(Temp,INDHHIN2,wt=WT)$n
  z=z[-c(11:12,15:17)]
  z=z/sum(z)
  return(chisq.test(x=z,p=Income_pretty$NHANES)$statistic)
})
1-ecdf(zz)(chisq.test(x=Income_pretty$Proportion,p=Income_pretty$NHANES)$statistic)

#Dichotomize income to above/below NHANES median
Income_Med=apply(WTS,2,function(x){
  Temp=data.frame(INDHHIN2=Full$INDHHIN2,WT=x)
  z=count(Temp,INDHHIN2,wt=WT)$n
  z=z[-c(11:12,15:17)]
  z=c(sum(z[1:8]),sum(z[9:12]))
  z=z/sum(z)
})
rowMeans(Income_Med)
quantile(Income_Med[1,],probs=c(0.025,0.975))

#Hypothesis Testing
chisq.test(x=rowMeans(Income_Med)*200000,p=c(sum(Income_pretty$NHANES[1:8]),sum(Income_pretty$NHANES[9:12])))
#Bootstrap
#Distribution of null chi squared statistics
zz=apply(WTS_null,2,function(x){
  Temp=data.frame(INDHHIN2=Full$INDHHIN2,WT=x)
  z=count(Temp,INDHHIN2,wt=WT)$n
  z=z[-c(11:12,15:17)]
  z=c(sum(z[1:8]),sum(z[9:12]))
  z=z/sum(z)
  return(chisq.test(x=z,p=c(sum(Income_pretty$NHANES[1:8]),sum(Income_pretty$NHANES[9:12])))$statistic)
})
1-ecdf(zz)(chisq.test(x=rowMeans(Income_Med),p=c(sum(Income_pretty$NHANES[1:8]),sum(Income_pretty$NHANES[9:12])))$statistic)

#Education Distribution
Educ=apply(WTS,2,function(x){
  Temp=data.frame(DMDEDUC2=Full$DMDEDUC2,WT=x)
  return(count(Temp,DMDEDUC2,wt=WT)$n)})
Educ=Educ/sum(Educ[,1])

Educ_complete=Educ[-c(6:9),]
Educ_complete=apply(Educ_complete,2,function(x){x/sum(x)})
Educ_pretty=data.frame(Education=factor(c("Less than 9th Grade","9th-11th Grade","High School/GED","Some College or AA","College or Above"),levels=c("Less than 9th Grade","9th-11th Grade","High School/GED","Some College or AA","College or Above")),
                       Median = apply(Educ_complete,1,quantile,prob=0.5),Proportion = apply(Educ_complete,1,mean),
                       Lower = apply(Educ_complete,1,quantile,prob=0.025),Upper = apply(Educ_complete,1,quantile,prob=0.975))

#Get NHANES proportions of education levels
zz=count(Full,DMDEDUC2,wt=WTMEC2YR)
zz=zz[1:5,]
Educ_pretty$NHANES=pull(zz,n)/sum(pull(zz,n))

ggplot(Educ_pretty)+geom_col(aes(x=Education,y=Proportion))+geom_errorbar(aes(x=Education,ymin=Lower,ymax=Upper),width=0.5)+
  geom_point(aes(x=Education,y=NHANES),col="red",shape=17,size=5)+theme(axis.text.x = element_text(angle = 60, hjust = 1))

#Hypothesis Testing
chisq.test(x=Educ_pretty$Proportion*200000,p=Educ_pretty$NHANES)
#Bootstrap
#Distribution of null chi squared statistics
zz=apply(WTS_null,2,function(x){
  Temp=data.frame(Educ=Full$DMDEDUC2,WT=x)
  z=count(Temp,Educ,wt=WT)$n
  z=z[1:5]
  z=z/sum(z)
  return(chisq.test(x=z,p=Educ_pretty$NHANES)$statistic)
})
1-ecdf(zz)(chisq.test(x=Educ_pretty$Proportion,p=Educ_pretty$NHANES)$statistic)

#Dichotomize to less/more than HS
Educ_HS = rbind(colSums(Educ_complete[1:2,]),colSums(Educ_complete[3:5,]))
mean(Educ_HS[1,]) #Avg proportion w/ less than HS education
quantile(Educ_HS[1,],probs = c(0.025,0.975)) #95% CI for proportion

#Hypothesis Testing
chisq.test(x=rowMeans(Educ_HS)*200000,p=c(sum(Educ_pretty$NHANES[1:2]),sum(Educ_pretty$NHANES[3:5])))
#Bootstrap
#Distribution of null chi squared statistics
zz=apply(WTS_null,2,function(x){
  Temp=data.frame(Educ=Full$DMDEDUC2,WT=x)
  z=count(Temp,Educ,wt=WT)$n
  z=c(sum(z[1:2]),sum(z[3:5]))
  z=z/sum(z)
  return(chisq.test(x=z,p=c(sum(Educ_pretty$NHANES[1:2]),sum(Educ_pretty$NHANES[3:5])))$statistic)
})
1-ecdf(zz)(chisq.test(x=rowMeans(Educ_HS),p=c(sum(Educ_pretty$NHANES[1:2]),sum(Educ_pretty$NHANES[3:5])))$statistic)

#Veteran Status Distribution
Vet=apply(WTS,2,function(x){
  Temp=data.frame(DMQMILIZ=Full$DMQMILIZ,WT=x)
  return(count(Temp,DMQMILIZ,wt=WT)$n)})
Vet=Vet/sum(Vet[,1])
Vet=Vet[1:2,]

Vet_complete=apply(Vet,2,function(x){x/sum(x)})
Vet_pretty=data.frame(Veteran_Status=c("Veteran","Not Veteran"),Median = apply(Vet_complete,1,quantile,prob=0.5),
                      Proportion = apply(Vet_complete,1,mean),
                      Lower = apply(Vet_complete,1,quantile,prob=0.025),Upper = apply(Vet_complete,1,quantile,prob=0.975))

#Get NHANES proportions of Veterans
zz=count(Full,DMQMILIZ,wt=WTMEC2YR)
zz=zz[1:2,]
Vet_pretty$NHANES=pull(zz,n)/sum(pull(zz,n))

ggplot(Vet_pretty)+geom_col(aes(x=Veteran_Status,y=Proportion),width=0.5)+geom_errorbar(aes(x=Veteran_Status,ymin=Lower,ymax=Upper),width=0.25)+
  geom_point(aes(x=Veteran_Status,y=NHANES),col="red",shape=17,size=5)+theme(axis.text.x = element_text(angle = 60, hjust = 1))

#Hypothesis Testing
chisq.test(x=Vet_pretty$Proportion*200000,p=Vet_pretty$NHANES)
#Bootstrap
#Distribution of null chi squared statistics
zz=apply(WTS_null,2,function(x){
  Temp=data.frame(Vet=Full$DMQMILIZ,WT=x)
  z=count(Temp,Vet,wt=WT)$n
  z=z[1:2]
  z=z/sum(z)
  return(chisq.test(x=z,p=Vet_pretty$NHANES)$statistic)
})
#Quantile
1-ecdf(zz)(chisq.test(x=Vet_pretty$Proportion,p=Vet_pretty$NHANES)$statistic)


#Figure for publication showing results for race/ethnicity, income, education, and veteran status
whites_plot=ggplot(RE_white_pretty)+geom_col(aes(x=Race_Ethnicity,y=Proportion),width=0.5)+geom_errorbar(aes(x=Race_Ethnicity,ymin=Lower,ymax=Upper),width=0.25,size=2)+
  geom_point(aes(x=Race_Ethnicity,y=CDC),colour="blue",size=5)+geom_point(aes(x=Race_Ethnicity,y=NHANES),colour="red",shape=17,size=5)+
  theme(text=element_text(size=20))+xlab("Race/Ethnicity")
re_plot=ggplot(RE_pretty)+geom_col(aes(x=Race_Ethnicity,y=Proportion))+geom_errorbar(aes(x=Race_Ethnicity,ymin=Lower,ymax=Upper),width=0.5,size=2)+
  geom_point(aes(x=Race_Ethnicity,y=CDC),colour="blue",size=5)+geom_point(aes(x=Race_Ethnicity,y=NHANES),colour="red",shape=17,size=5)+
  theme(axis.text.x = element_text(angle = 45, hjust = 1),text=element_text(size=20))+xlab("Race/Ethnicity")
inc_plot=ggplot(Income_pretty)+geom_col(aes(x=Income,y=Proportion))+geom_errorbar(aes(x=Income,ymin=Lower,ymax=Upper),width=0.5,size=2)+
  geom_point(aes(x=Income,y=NHANES),col="red",shape=17,size=5)+theme(axis.text.x = element_text(angle = 60, hjust = 1),text=element_text(size=20))
educ_plot=ggplot(Educ_pretty)+geom_col(aes(x=Education,y=Proportion))+geom_errorbar(aes(x=Education,ymin=Lower,ymax=Upper),width=0.5,size=2)+
  geom_point(aes(x=Education,y=NHANES),col="red",shape=17,size=5)+theme(axis.text.x = element_text(angle = 60, hjust = 1),text=element_text(size=20))
vet_plot=ggplot(Vet_pretty)+geom_col(aes(x=Veteran_Status,y=Proportion),width=0.5)+geom_errorbar(aes(x=Veteran_Status,ymin=Lower,ymax=Upper),width=0.25,size=2)+
  geom_point(aes(x=Veteran_Status,y=NHANES),col="red",shape=17,size=5)+theme(text = element_text(size=20))+xlab("Veteran Status")
ggsave("Distributions20200915.pdf",grid.arrange(whites_plot,inc_plot,educ_plot,vet_plot,ncol=2),height=12,width=16)
ggsave("Distributions20200915.tiff",grid.arrange(whites_plot,inc_plot,educ_plot,vet_plot,ncol=2),height=12,width=16)

ggsave("Race_Ethnicity20200915.pdf",re_plot,height=6,width=8)
ggsave("Race_Ethnicity20200915.tiff",re_plot,height=6,width=8)

##Bootstrap Logistic Regression model of SDoH and COVID mortality
#Get control group, which wil also contain covariates for cases
Controls=subset(Full,select=c(SEQN,RIDAGEYR,RIAGENDR,RIDRETH3,INDHHIN2,DMDEDUC2,DMQMILIZ,DMDHHSIZ,WTMEC2YR))
Controls$RIDRETH3[which(Controls$RIDRETH3==2)]=1 #Group all people of Hispanic ethnicity together
Controls$RIDRETH3=factor(Controls$RIDRETH3,levels=c(3,1,4,6,7),labels=c("NHW","Hispanic","AA","AAPI","Other")) #Set NHW as reference group
Controls$INDHHIN2[which(Controls$INDHHIN2%in%c(11,12,13,77,99))]=NA #Replace income values not used with NA
Controls$INDHHIN2=factor(Controls$INDHHIN2,labels=c(2500,7500,12500,17500,22500,30000,40000,50000,60000,70000,87500,100000)) #Convert income to factor
Controls$INDHHIN2=as.numeric(as.character(Controls$INDHHIN2))/1000 #Convert income factor to continuous value in thousands of USD
Controls$DMDEDUC2[which(Controls$DMDEDUC2%in%c(7,9))]=NA #Replace missing education levels with NA
Controls$DMDEDUC2=factor(Controls$DMDEDUC2,levels=c(3,1,2,4,5),labels=c("High School/GED","Less than 9th Grade","9th-11th Grade",
                  "Some College or AA","College or Above"))
Controls$DMQMILIZ[which(Controls$DMQMILIZ%in%c(7,9))]=NA #Replace missing veteran status with NA
Controls$RIAGENDR=Controls$RIAGENDR-1 #Convert gender to 0 = male, 1 = female
Controls$DMQMILIZ=abs(Controls$DMQMILIZ-2) #Convert veteran status to 0 = not a vet, 1 = vet
Controls$HHSIZ=factor(Controls$DMDHHSIZ,levels=1:7,labels=c("1","2","3","4","5","6",">=7"))
Controls$Mort=0 #Mortality variable


#Bootstrap regressions
z=matrix(nrow=ncol(WTS),ncol=13)#names=
for(i in 1:ncol(WTS)){
  Cases=Controls #Get covariates for cases
  Cases$Mort=rep(1,nrow(Cases)) #Define cases as having died
  Cases$WTMEC2YR=WTS[,i] #Weight cases
  z[i,]=glm(Mort ~ RIDAGEYR+RIAGENDR+RIDRETH3+INDHHIN2+DMDEDUC2+DMQMILIZ,family=binomial,data=rbind(Cases,Controls),weights=WTMEC2YR)$coefficients
}

ests = as.data.frame(apply(z,2,quantile,probs=c(0.025,0.5,0.975)))
names(ests) = c("Intercept","Age","Gender","Hispanic","AA","AAPI","Other","Income","<9th Grade","9th-11th Grade","Some College","College","Veteran")
ests=rbind(apply(z,2,mean),ests)
row.names(ests)[1]="mean"

write.csv(ests,"Logistic Regression.csv")

#Bootstrap Null Hypothesis Results
z=matrix(nrow=ncol(WTS_null),ncol=13)#names=
for(i in 1:ncol(WTS_null)){
  Cases=Controls #Get covariates for cases
  Cases$Mort=rep(1,nrow(Cases)) #Define cases as having died
  Cases$WTMEC2YR=WTS_null[,i] #Weight cases
  z[i,]=glm(Mort ~ RIDAGEYR+RIAGENDR+RIDRETH3+INDHHIN2+DMDEDUC2+DMQMILIZ,family=binomial,data=rbind(Cases,Controls),weights=WTMEC2YR)$coefficients
}

ests_null = as.data.frame(apply(z,2,quantile,probs=c(0.025,0.5,0.975)))
names(ests_null) = c("Intercept","Age","Gender","Hispanic","AA","AAPI","Other","Income","<9th Grade","9th-11th Grade","Some College","College","Veteran")
ests_null=rbind(apply(z,2,mean),ests_null)
row.names(ests_null)[1]="mean"

#Estimate p-values for each coefficient
for(i in 1:ncol(ests)){
  print(names(ests)[i])
  #Next: Take ith column of z (for nulls) centered on mean and take absolute values, get empirical distribution
  #Then locate the mean coefficient i from the regression on simulated data, center, and locate percentile
  #on empirical distribution. Subtract from one. (i.e. if at extreme of empirical distribution, p approaches 0)
  print(1-ecdf(abs(z[,i]-mean(z[,i])))(abs(ests[1,i]-mean(z[,i]))))
}

#Produce data frame with results
Results = data.frame(Variable = vector(),Coefficient = vector(),CI = vector(),pvalue = vector())
for(i in 2:ncol(ests)){
  Coef = exp(ests["mean",i])
  CI = paste(exp(ests["2.5%",i]),"-",exp(ests["97.5%",i]))
  pval = 1-ecdf(abs(z[,i]-mean(z[,i])))(abs(ests[1,i]-mean(z[,i])))
  Results = rbind(Results,data.frame(Variable = names(ests)[i], 
                  Coefficient = Coef, CI = CI, pvalue = pval))
}
write.csv(Results,file = "Regression Results.csv",row.names = FALSE)
