#Step 1
#Load in data from 2017-18 NHANES for data that will be drawn to produce population of deaths from COVID-19
#setwd("Desktop/COVID-19/Code")
library(foreign)
library(wCorr)
setwd("../NHANES")

#Core Demographic Data
#Note: Interview sampling weight is WTINT2YR, Exam sampling weight is WTMEC2YR
Core=read.xport("DEMO_J.XPT")

#Diabetes Variable
A1C=read.xport("GHB_J.XPT") #A1C data
DIQ=read.xport("DIQ_J.XPT") #DM questionnaire
DM=merge(A1C,DIQ[,c("SEQN","DIQ010")],by="SEQN")

DM$DM = as.numeric((DM$LBXGH>=6.5)|(DM$DIQ010==1)) #Diabetes yes/no by A1C & self-report

#Hypertension Variable
BP=read.xport("BPX_J.XPT") #Blood Pressure data
BP$SBP=apply(BP[,c("BPXSY1","BPXSY2","BPXSY3","BPXSY4")],1,mean,na.rm=T) #mean SBP
BP$DBP=apply(BP[,c("BPXDI1","BPXDI2","BPXDI3","BPXDI4")],1,mean,na.rm=T) #mean DBP
BPQ=read.xport("BPQ_J.XPT") #BP questionnaire

HTN=merge(BP[,c("SEQN","SBP","DBP")],BPQ[,c("SEQN","BPQ020","BPQ040A")],by="SEQN")
HTN$HTN_Meds=as.numeric((HTN$SBP>=140)|(HTN$DBP>=90)|(HTN$BPQ040A==1)) #HTN yes/no by BP & taking meds
HTN$HTN=as.numeric((HTN$SBP>=140)|(HTN$DBP>=90)|(HTN$BPQ020==1)) #HTN yes/no by BP & self-report

#Cardiovascular Disease (other than HTN)
MCQ = read.xport("MCQ_J.XPT")
MCQ$CVD = as.numeric((MCQ$MCQ160B==1)|(MCQ$MCQ160C==1)|(MCQ$MCQ160D==1)|(MCQ$MCQ160E==1)|(MCQ$MCQ160F==1)) #CVD, 
#including heart failure (MCQ160b) and stroke (MCQ160f)
MCQ$IHD = as.numeric((MCQ$MCQ160C==1)|(MCQ$MCQ160D==1)|(MCQ$MCQ160E==1)) #ischemic heart disease only (CHD, angina
#or myocardial infarction)

#Other Conditions
#COPD
MCQ$COPD = as.numeric((MCQ$MCQ160G==1)|(MCQ$MCQ160K==1)|(MCQ$MCQ160O==1))
#CKD
KIQ=read.xport("KIQ_U_J.XPT")
KIQ$CKD_1= as.numeric((KIQ$KIQ022==1)|(KIQ$KIQ025==1))#Self-Report
ALB_CR=read.xport("ALB_CR_J.XPT")
ALB_CR$CKD_2=as.numeric(ALB_CR$URDACT<30)#Microalbuminuria
KIQ=merge(KIQ,ALB_CR[,c("SEQN","CKD_2")],by="SEQN")
BIOPRO=read.xport("BIOPRO_J.XPT")
BIOPRO=merge(BIOPRO,Core[,c("SEQN","RIAGENDR","RIDAGEYR","RIDRETH3")])
BIOPRO$Black=as.numeric(BIOPRO$RIDRETH3==4)
CKDEPI=function(Sex,Cr,Age,Black){
  if(Sex==2){#Females
    if(Cr<=0.7){return(144*(x$Cr/0.7)^(-0.329)*0.993^(x$Age)*1.159^(Black))}
    else{return(144*(x$Cr/0.7)^(-1.209)*0.993^(Age)*1.159^(Black))}
  }
  if(Sex==1){#Males
    if(Cr<=0.7){return(141*(Cr/0.9)^(-0.411)*0.993^(Age)*1.159^(Black))}
    else{return(141*(Cr/0.9)^(-1.209)*0.993^(Age)*1.159^(Black))}
  }
}
BIOPRO$CKD_3=apply(BIOPRO,1,function(x){#CKD-EPI Creatinine
  if(is.na(x[13])==T|is.na(x[42])==T|is.na(x[43])==T|is.na(x[45])==T){return(NA)}
  else if(x[42]==2){#Females
    if(x[13]<=0.7){return(144*(x[13]/0.7)^(-0.329)*0.993^(x[43])*1.159^(x[45]))}
    else if(x[13]>0.7){return(144*(x[13]/0.7)^(-1.209)*0.993^(x[43])*1.159^(x[45]))}
    else{reutnr(NA)}
  }
  else if(x[42]==1){#Males
    if(x[13]<=0.7){return(141*(x[13]/0.9)^(-0.411)*0.993^(x[43])*1.159^(x[45]))}
    else if(x[13]>0.7){return(141*(x[13]/0.9)^(-1.209)*0.993^(x[43])*1.159^(x[45]))}
    else{return(NA)}
  }
  else{return(NA)}
})
BIOPRO$CKD_3=as.numeric(BIOPRO$CKD_3<60)
KIQ=merge(KIQ,BIOPRO[,c("SEQN","CKD_3")],by="SEQN")
#Identify CKD (any of possible definitions is positive)
z=KIQ[,c("SEQN","CKD_1","CKD_2","CKD_3")]

z$CKD=apply(z,1,function(x){
  if(1%in%x[c(2,4)]){return(1)}
  else if(is.na(x[2]==T)&is.na(x[4]==T)){return(NA)}
  else{return(0)}
})
KIQ=merge(KIQ,z[,c("SEQN","CKD")],by="SEQN")

#Comorbidity Count
MCQ=merge(MCQ,KIQ[,c("SEQN","CKD")],by="SEQN")
MCQ=merge(MCQ,HTN[,c("SEQN","HTN")],by="SEQN")
MCQ=merge(MCQ,DM[,c("SEQN","DM")],by="SEQN")
MCQ$CA=as.numeric(MCQ$MCQ220==1)
MCQ$asthma=apply(MCQ,1,function(x){#Asthma: ever told & still have = 1, missing data leads to missing, else 
  #do not have asthma
#  if(is.na(x[2])){return(NA)}
  if((x[2]%in%1)&(x[4]%in%1)){return(1)}#If ever told & still has asthma --> return 1
  else if(x[2]%in%2|x[4]%in%2){return(0)}
  else{return(NA)}
})

#Sum comorbidities, including asthma, CHF & stroke separate from CAD, liver disease (MCQ160l), and
#cancer (MCQ220)
MCQ$CMC= MCQ$HTN+MCQ$CKD+MCQ$DM+MCQ$IHD+MCQ$COPD+MCQ$asthma+MCQ$MCQ160B+MCQ$MCQ160F+MCQ$MCQ160L+MCQ$MCQ220
MCQ$NoComorb=as.numeric(MCQ$CMC==0) #Dummy variable for people with no comorbid illness


#Full Dataset
Full = merge(Core,MCQ,by="SEQN")
Full = Full[which(Full$RIDAGEYR>=20),] #Limit sample to adults >= 20 years of age
Full$age = cut(Full$RIDAGEYR,seq(20,85,5),right=FALSE)
Full$male=abs(Full$RIAGENDR-2) #Make male a binary variable with 1 - male (original coding is 1 = male, 2 = female)

#Categorical race/ethnicity variable
Full$RE=factor(Full$RIDRETH3,levels=c(3,1,2,4,6,7),labels=c("WH","HS","HS","AA","AS","OT"))
Full=cbind(Full,model.matrix(~Full$RE+0))
names(Full)[(ncol(Full)-4):ncol(Full)]=c("REWH","REHS","REAA","REAS","REOT")#Dummy variables for each race/ethnicity

#Spearman Correlation Matrix
CorData=subset(Full,select=c(age,male,HTN,DM,IHD,CKD,COPD,CA,NoComorb,REWH,WTMEC2YR,SEQN))
CorData$age=as.numeric(ordered(CorData$age))
CorData=CorData[complete.cases(CorData),]
Cors=diag(10)
for(i in 1:9){
  for(j in (i+1):10){
    Cors[i,j]=Cors[j,i]=weightedCorr(CorData[,i],CorData[,j],method="Spearman",weights=CorData$WTMEC2YR)
  }
}

setwd("../Code")
